@@ -27,8 +27,9 @@ portage.proxy.lazyimport.lazyimport(
 
 
 class AbstractEbuildProcess(SpawnProcess):
-
-    __slots__ = ("phase", "settings",) + (
+    __slots__ = (
+        "phase",
+        "settings",
         "_build_dir",
         "_build_dir_unlock",
         "_ipc_daemon",
@@ -65,7 +66,6 @@ class AbstractEbuildProcess(SpawnProcess):
             self.phase = phase
 
     def _start(self):
-
         need_builddir = self.phase not in self._phases_without_builddir
 
         # This can happen if the pre-clean phase triggers
@@ -159,9 +159,7 @@ class AbstractEbuildProcess(SpawnProcess):
 
                 cgroup_path = tempfile.mkdtemp(
                     dir=cgroup_portage,
-                    prefix="{}:{}.".format(
-                        self.settings["CATEGORY"], self.settings["PF"]
-                    ),
+                    prefix=f"{self.settings['CATEGORY']}:{self.settings['PF']}.",
                 )
             except (subprocess.CalledProcessError, OSError):
                 pass
@@ -249,12 +247,10 @@ class AbstractEbuildProcess(SpawnProcess):
                 os.close(null_fd)
 
     def _init_ipc_fifos(self):
-
         input_fifo = os.path.join(self.settings["PORTAGE_BUILDDIR"], ".ipc", "in")
         output_fifo = os.path.join(self.settings["PORTAGE_BUILDDIR"], ".ipc", "out")
 
         for p in (input_fifo, output_fifo):
-
             st = None
             try:
                 st = os.lstat(p)
@@ -356,7 +352,6 @@ class AbstractEbuildProcess(SpawnProcess):
         self._eerror(textwrap.wrap(msg, 72))
 
     def _unexpected_exit(self):
-
         phase = self.phase
 
         msg = (
@@ -453,9 +448,7 @@ class AbstractEbuildProcess(SpawnProcess):
             SpawnProcess._async_wait(self)
         elif self._build_dir_unlock is None:
             if self.returncode is None:
-                raise asyncio.InvalidStateError(
-                    "Result is not ready for {}".format(self)
-                )
+                raise asyncio.InvalidStateError(f"Result is not ready for {self}")
             self._async_unlock_builddir(returncode=self.returncode)
 
     def _async_unlock_builddir(self, returncode=None):
