@@ -75,7 +75,7 @@ class _RepoDisplay:
             show_repo_paths[repo_index] = repo_path
         if show_repo_paths:
             for index, repo_path in enumerate(show_repo_paths):
-                output.append(" " + teal("[" + str(index) + "]") + " %s\n" % repo_path)
+                output.append(" " + teal("[" + str(index) + "]") + f" {repo_path}\n")
         if unknown_repo:
             output.append(
                 " "
@@ -107,47 +107,45 @@ class _PackageCounters:
         )
         myoutput = []
         details = []
-        myoutput.append("Total: %s package" % total_installs)
+        myoutput.append(f"Total: {total_installs} package")
         if total_installs != 1:
             myoutput.append("s")
         if total_installs != 0:
             myoutput.append(" (")
         if self.upgrades > 0:
-            details.append("%s upgrade" % self.upgrades)
+            details.append(f"{self.upgrades} upgrade")
             if self.upgrades > 1:
                 details[-1] += "s"
         if self.downgrades > 0:
-            details.append("%s downgrade" % self.downgrades)
+            details.append(f"{self.downgrades} downgrade")
             if self.downgrades > 1:
                 details[-1] += "s"
         if self.new > 0:
-            details.append("%s new" % self.new)
+            details.append(f"{self.new} new")
         if self.newslot > 0:
-            details.append("%s in new slot" % self.newslot)
+            details.append(f"{self.newslot} in new slot")
             if self.newslot > 1:
                 details[-1] += "s"
         if self.reinst > 0:
-            details.append("%s reinstall" % self.reinst)
+            details.append(f"{self.reinst} reinstall")
             if self.reinst > 1:
                 details[-1] += "s"
         if self.binary > 0:
-            details.append("%s binary" % self.binary)
+            details.append(f"{self.binary} binary")
             if self.binary > 1:
                 details[-1] = details[-1][:-1] + "ies"
         if self.uninst > 0:
-            details.append("%s uninstall" % self.uninst)
+            details.append(f"{self.uninst} uninstall")
             if self.uninst > 1:
                 details[-1] += "s"
         if self.interactive > 0:
-            details.append(
-                "%s %s" % (self.interactive, colorize("WARN", "interactive"))
-            )
+            details.append(f"{self.interactive} {colorize('WARN', 'interactive')}")
         myoutput.append(", ".join(details))
         if total_installs != 0:
             myoutput.append(")")
-        myoutput.append(", Size of downloads: %s" % localized_size(self.totalsize))
+        myoutput.append(f", Size of downloads: {localized_size(self.totalsize)}")
         if self.restrict_fetch:
-            myoutput.append("\nFetch Restriction: %s package" % self.restrict_fetch)
+            myoutput.append(f"\nFetch Restriction: {self.restrict_fetch} package")
             if self.restrict_fetch > 1:
                 myoutput.append("s")
         if self.restrict_fetch_satisfied < self.restrict_fetch:
@@ -156,7 +154,7 @@ class _PackageCounters:
                 % (self.restrict_fetch - self.restrict_fetch_satisfied)
             )
         if self.blocks > 0:
-            myoutput.append("\nConflict: %s block" % self.blocks)
+            myoutput.append(f"\nConflict: {self.blocks} block")
             if self.blocks > 1:
                 myoutput.append("s")
             if self.blocks_satisfied < self.blocks:
@@ -205,7 +203,7 @@ class _DisplayConfig:
             try:
                 mywidth = int(frozen_config.settings["COLUMNWIDTH"])
             except ValueError as e:
-                writemsg("!!! %s\n" % str(e), noiselevel=-1)
+                writemsg(f"!!! {str(e)}\n", noiselevel=-1)
                 writemsg(
                     "!!! Unable to parse COLUMNWIDTH='%s'\n"
                     % frozen_config.settings["COLUMNWIDTH"],
@@ -272,7 +270,6 @@ def _create_use_string(
     feature_flags,
     reinst_flags,
 ):
-
     if not conf.print_use_string:
         return ""
 
@@ -339,21 +336,20 @@ def _create_use_string(
     else:
         ret = " ".join(enabled + disabled + removed)
     if ret:
-        ret = '%s="%s" ' % (name, ret)
+        ret = f'{name}="{ret}" '
     return ret
 
 
 def _tree_display(conf, mylist):
-
     # If there are any Uninstall instances, add the
     # corresponding blockers to the digraph.
     mygraph = conf.digraph.copy()
 
-    executed_uninstalls = set(
+    executed_uninstalls = {
         node
         for node in mylist
         if isinstance(node, Package) and node.operation == "unmerge"
-    )
+    }
 
     for uninstall in conf.blocker_uninstalls.leaf_nodes():
         uninstall_parents = conf.blocker_uninstalls.parent_nodes(uninstall)
@@ -418,7 +414,6 @@ def _unordered_tree_display(mygraph, mylist):
     seen_nodes = set()
 
     def print_node(node, depth):
-
         if node in seen_nodes:
             pass
         else:
@@ -593,7 +588,6 @@ class PkgInfo:
 
 
 class PkgAttrDisplay(SlotObject):
-
     __slots__ = (
         "downgrade",
         "fetch_restrict",
