@@ -18,7 +18,6 @@ from _emerge.Package import Package
 
 
 class search:
-
     #
     # class constants
     #
@@ -107,7 +106,7 @@ class search:
 
     def _aux_get_error(self, cpv):
         portage.writemsg(
-            "emerge: search: " "aux_get('%s') failed, skipping\n" % cpv, noiselevel=-1
+            f"emerge: search: aux_get('{cpv}') failed, skipping\n", noiselevel=-1
         )
 
     def _findname(self, *args, **kwargs):
@@ -152,7 +151,6 @@ class search:
         ).visible
 
     def _first_cp(self, cp):
-
         for db in self._dbs:
             if hasattr(db, "cp_list"):
                 matches = db.cp_list(cp)
@@ -249,7 +247,6 @@ class search:
         self.searchkey = searchkey
 
     def _iter_search(self):
-
         match_category = 0
         self.packagematches = []
         if self.searchdesc:
@@ -475,15 +472,13 @@ class search:
                     try:
                         uri_map = _parse_uri_map(mycpv, metadata, use=pkg.use.enabled)
                     except portage.exception.InvalidDependString as e:
-                        file_size_str = "Unknown (%s)" % (e,)
+                        file_size_str = f"Unknown ({e})"
                         del e
                     else:
                         try:
                             mysum[0] = mf.getDistfilesSize(uri_map)
                         except KeyError as e:
-                            file_size_str = "Unknown (missing " + "digest for %s)" % (
-                                e,
-                            )
+                            file_size_str = "Unknown (missing " + f"digest for {e})"
                             del e
 
                 available = False
@@ -511,12 +506,11 @@ class search:
                             % (darkgreen("Latest version available:"), myversion)
                         )
                     msg.append(
-                        "      %s\n" % self.getInstallationStatus(mycat + "/" + mypkg)
+                        f"      {self.getInstallationStatus(mycat + '/' + mypkg)}\n"
                     )
                     if myebuild:
                         msg.append(
-                            "      %s %s\n"
-                            % (darkgreen("Size of files:"), file_size_str)
+                            f"      {darkgreen('Size of files:')} {file_size_str}\n"
                         )
                     msg.append(
                         "      " + darkgreen("Homepage:") + "      " + homepage + "\n"
