@@ -5,6 +5,8 @@ import logging
 import re
 import subprocess
 
+from typing import Tuple
+
 import portage
 from portage import os
 from portage.util import writemsg_level, shlex_split
@@ -35,11 +37,11 @@ class GitSync(NewBase):
     def __init__(self):
         NewBase.__init__(self, "git", portage.const.GIT_PACKAGE_ATOM)
 
-    def exists(self, **kwargs):
+    def exists(self, **kwargs) -> bool:
         """Tests whether the repo actually exists"""
         return os.path.exists(os.path.join(self.repo.location, ".git"))
 
-    def new(self, **kwargs):
+    def new(self, **kwargs) -> Tuple[int, bool]:
         """Do the initial clone of the repository"""
         if kwargs:
             self._kwargs(kwargs)
@@ -49,7 +51,7 @@ class GitSync(NewBase):
             if not os.path.exists(self.repo.location):
                 os.makedirs(self.repo.location)
                 self.logger(
-                    self.xterm_titles, "Created new directory %s" % self.repo.location
+                    self.xterm_titles, f"Created new directory {self.repo.location}"
                 )
         except OSError:
             return (1, False)
@@ -90,7 +92,7 @@ class GitSync(NewBase):
 
         if self.repo.module_specific_options.get("sync-git-clone-extra-opts"):
             git_cmd_opts += (
-                " %s" % self.repo.module_specific_options["sync-git-clone-extra-opts"]
+                f" {self.repo.module_specific_options['sync-git-clone-extra-opts']}"
             )
         git_cmd = "{} clone{} {} .".format(
             self.bin_command,
@@ -100,11 +102,11 @@ class GitSync(NewBase):
         writemsg_level(git_cmd + "\n")
 
         exitcode = portage.process.spawn_bash(
-            "cd {} ; exec {}".format(portage._shell_quote(self.repo.location), git_cmd),
+            f"cd {portage._shell_quote(self.repo.location)} ; exec {git_cmd}",
             **self.spawn_kwargs,
         )
         if exitcode != os.EX_OK:
-            msg = "!!! git clone error in %s" % self.repo.location
+            msg = f"!!! git clone error in {self.repo.location}"
             self.logger(self.xterm_titles, msg)
             writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
             return (exitcode, False)
@@ -116,12 +118,11 @@ class GitSync(NewBase):
 
         return (os.EX_OK, True)
 
-    def _gen_ceiling_string(self, path):
+    def _gen_ceiling_string(self, path: str) -> str:
         """
         Iteratively generate a colon delimited string of all of the
         given path's parents, for use with GIT_CEILING_DIRECTORIES
         """
-        path = self.repo.location
         directories = []
 
         while True:
@@ -132,7 +133,7 @@ class GitSync(NewBase):
 
         return ":".join(directories)
 
-    def update(self):
+    def update(self) -> Tuple[int, bool]:
         """Update existing git repository, and ignore the syncuri. We are
         going to trust the user and assume that the user is in the branch
         that he/she wants updated. We'll let the user manage branches with
@@ -169,7 +170,7 @@ class GitSync(NewBase):
             }
             self.spawn_kwargs["env"].update(pull_env)
 
-        if self.settings.get("PORTAGE_QUIET") == "1":
+        if quiet:
             git_cmd_opts += " --quiet"
 
         # The logic here is a bit delicate. We need to balance two things:
@@ -194,13 +195,14 @@ class GitSync(NewBase):
         # 1. sync-type=git
         # 2.
         #   - volatile=no (explicitly set to no), OR
-        #   - volatile is unset AND the repository owner is neither root or portage
+        #   - volatile is unset AND the repository owner is either root or portage
         # 3. Portage is syncing the respository (rather than e.g. auto-sync=no
         # and never running 'emaint sync -r foo')
         #
         # Portage will not clobber if:
         # 1. volatile=yes (explicitly set in the config), OR
-        # 2. volatile is unset and the repository owner is root or portage.
+        # 2. volatile is unset and the repository owner is neither root nor
+        #    portage.
         #
         # 'volatile' refers to whether the repository is volatile and may
         # only be safely changed by Portage itself, i.e. whether Portage
@@ -252,7 +254,7 @@ class GitSync(NewBase):
 
         if self.repo.module_specific_options.get("sync-git-pull-extra-opts"):
             git_cmd_opts += (
-                " %s" % self.repo.module_specific_options["sync-git-pull-extra-opts"]
+                f" {self.repo.module_specific_options['sync-git-pull-extra-opts']}"
             )
 
         self.add_safe_directory()
@@ -271,7 +273,7 @@ class GitSync(NewBase):
                 )
             ).rstrip("\n")
         except subprocess.CalledProcessError as e:
-            msg = "!!! git rev-parse error in %s" % self.repo.location
+            msg = f"!!! git rev-parse error in {self.repo.location}"
             self.logger(self.xterm_titles, msg)
             writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
             return (e.returncode, False)
@@ -289,7 +291,7 @@ class GitSync(NewBase):
                 **self.spawn_kwargs,
             )
             if exitcode != os.EX_OK:
-                msg = "!!! git gc error in %s" % self.repo.location
+                msg = f"!!! git gc error in {self.repo.location}"
                 self.logger(self.xterm_titles, msg)
                 writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
                 return (exitcode, False)
@@ -300,7 +302,8 @@ class GitSync(NewBase):
             git_cmd_opts,
         )
 
-        writemsg_level(git_cmd + "\n")
+        if not quiet:
+            writemsg_level(git_cmd + "\n")
 
         rev_cmd = [self.bin_command, "rev-list", "--max-count=1", "HEAD"]
         previous_rev = subprocess.check_output(
@@ -308,17 +311,17 @@ class GitSync(NewBase):
         )
 
         exitcode = portage.process.spawn_bash(
-            "cd {} ; exec {}".format(portage._shell_quote(self.repo.location), git_cmd),
+            f"cd {portage._shell_quote(self.repo.location)} ; exec {git_cmd}",
             **self.spawn_kwargs,
         )
 
         if exitcode != os.EX_OK:
-            msg = "!!! git fetch error in %s" % self.repo.location
+            msg = f"!!! git fetch error in {self.repo.location}"
             self.logger(self.xterm_titles, msg)
             writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
             return (exitcode, False)
 
-        if not self.verify_head(revision="refs/remotes/%s" % remote_branch):
+        if not self.verify_head(revision=f"refs/remotes/{remote_branch}"):
             return (1, False)
 
         if not self.repo.volatile:
@@ -339,7 +342,7 @@ class GitSync(NewBase):
             )
 
             if exitcode != os.EX_OK:
-                msg = "!!! git clean error in %s" % self.repo.location
+                msg = f"!!! git clean error in {self.repo.location}"
                 self.logger(self.xterm_titles, msg)
                 writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
                 return (exitcode, False)
@@ -365,28 +368,32 @@ class GitSync(NewBase):
         else:
             merge_cmd = [self.bin_command, "merge"]
 
-        merge_cmd.append("refs/remotes/%s" % remote_branch)
+        merge_cmd.append(f"refs/remotes/{remote_branch}")
         if quiet:
             merge_cmd.append("--quiet")
 
+        if not quiet:
+            writemsg_level(" ".join(merge_cmd) + "\n")
+
         exitcode = portage.process.spawn(
             merge_cmd,
             cwd=portage._unicode_encode(self.repo.location),
             **self.spawn_kwargs,
         )
 
-        if exitcode != os.EX_OK and not self.repo.volatile:
-            # HACK - sometimes merging results in a tree diverged from
-            # upstream, so try to hack around it
-            # https://stackoverflow.com/questions/41075972/how-to-update-a-git-shallow-clone/41081908#41081908
-            exitcode = portage.process.spawn(
-                f"{self.bin_command} reset --hard refs/remotes/{remote_branch}",
-                cwd=portage._unicode_encode(self.repo.location),
-                **self.spawn_kwargs,
-            )
+        if exitcode != os.EX_OK:
+            if not self.repo.volatile:
+                # HACK - sometimes merging results in a tree diverged from
+                # upstream, so try to hack around it
+                # https://stackoverflow.com/questions/41075972/how-to-update-a-git-shallow-clone/41081908#41081908
+                exitcode = portage.process.spawn(
+                    f"{self.bin_command} reset --hard refs/remotes/{remote_branch}",
+                    cwd=portage._unicode_encode(self.repo.location),
+                    **self.spawn_kwargs,
+                )
 
             if exitcode != os.EX_OK:
-                msg = "!!! git merge error in %s" % self.repo.location
+                msg = f"!!! git merge error in {self.repo.location}"
                 self.logger(self.xterm_titles, msg)
                 writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
                 return (exitcode, False)
@@ -397,7 +404,7 @@ class GitSync(NewBase):
 
         return (os.EX_OK, current_rev != previous_rev)
 
-    def verify_head(self, revision="-1"):
+    def verify_head(self, revision="-1") -> bool:
         if self.repo.module_specific_options.get(
             "sync-git-verify-commit-signature", "false"
         ).lower() not in ("true", "yes"):
@@ -418,16 +425,13 @@ class GitSync(NewBase):
             env = None
             if openpgp_env is not None and self.repo.sync_openpgp_key_path is not None:
                 try:
-                    out.einfo(
-                        "Using keys from {}".format(self.repo.sync_openpgp_key_path)
-                    )
+                    out.einfo(f"Using keys from {self.repo.sync_openpgp_key_path}")
                     with open(self.repo.sync_openpgp_key_path, "rb") as f:
                         openpgp_env.import_key(f)
                     self._refresh_keys(openpgp_env)
                 except (GematoException, asyncio.TimeoutError) as e:
                     writemsg_level(
-                        "!!! Verification impossible due to keyring problem:\n%s\n"
-                        % (e,),
+                        f"!!! Verification impossible due to keyring problem:\n{e}\n",
                         level=logging.ERROR,
                         noiselevel=-1,
                     )
@@ -468,13 +472,13 @@ class GitSync(NewBase):
                 expl = "no signature"
             else:
                 expl = "unknown issue"
-            out.eerror("No valid signature found: {}".format(expl))
+            out.eerror(f"No valid signature found: {expl}")
             return False
         finally:
             if openpgp_env is not None:
                 openpgp_env.close()
 
-    def retrieve_head(self, **kwargs):
+    def retrieve_head(self, **kwargs) -> Tuple[int, bool]:
         """Get information about the head commit"""
         if kwargs:
             self._kwargs(kwargs)
@@ -495,7 +499,7 @@ class GitSync(NewBase):
             ret = (1, False)
         return ret
 
-    def add_safe_directory(self):
+    def add_safe_directory(self) -> bool:
         # Add safe.directory to system gitconfig if not already configured.
         # Workaround for bug #838271 and bug #838223.
         location_escaped = re.escape(self.repo.location)
