@@ -1,6 +1,26 @@
 # Copyright 2004-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
+from portage.cache.mappings import UserDict
+from portage.proxy.objectproxy import ObjectProxy
+from portage.localization import _
+from portage.exception import (
+    InvalidAtom,
+    PortageException,
+    FileNotFound,
+    IsADirectory,
+    OperationNotPermitted,
+    ParseError,
+    PermissionDenied,
+    ReadOnlyFileSystem,
+)
+from portage.const import VCS_DIRS
+from portage import _unicode_decode
+from portage import _unicode_encode
+from portage import _os_merge
+from portage import _encodings
+from portage import os
+
 __all__ = [
     "apply_permissions",
     "apply_recursive_permissions",
@@ -61,26 +81,6 @@ portage.proxy.lazyimport.lazyimport(
     "subprocess",
 )
 
-from portage import os
-from portage import _encodings
-from portage import _os_merge
-from portage import _unicode_encode
-from portage import _unicode_decode
-from portage.const import VCS_DIRS
-from portage.exception import (
-    InvalidAtom,
-    PortageException,
-    FileNotFound,
-    IsADirectory,
-    OperationNotPermitted,
-    ParseError,
-    PermissionDenied,
-    ReadOnlyFileSystem,
-)
-from portage.localization import _
-from portage.proxy.objectproxy import ObjectProxy
-from portage.cache.mappings import UserDict
-
 
 noiselimit = 0
 
@@ -142,7 +142,7 @@ def writemsg_level(msg, level=0, noiselevel=0):
     writemsg(msg, noiselevel=noiselevel, fd=fd)
 
 
-def normalize_path(mypath):
+def normalize_path(mypath) -> str:
     """
     os.path.normpath("//foo") returns "//foo" instead of "/foo"
     We dislike this behavior so we create our own normpath func
@@ -573,7 +573,6 @@ def grabfile_package(
     eapi=None,
     eapi_default="0",
 ):
-
     pkgs = grabfile(
         myfilename, compatlevel, recursive=recursive, remember_source_file=True
     )
@@ -706,7 +705,7 @@ def writedict(mydict, myfilename, writekey=True):
             lines.append(v + "\n")
     else:
         for k, v in mydict.items():
-            lines.append("{} {}\n".format(k, " ".join(v)))
+            lines.append(f"{k} {' '.join(v)}\n")
     write_atomic(myfilename, "".join(lines))
 
 
@@ -736,7 +735,7 @@ class _getconfig_shlex(shlex.shlex):
             if e.errno == PermissionDenied.errno:
                 raise PermissionDenied(newfile)
             if e.errno not in (errno.ENOENT, errno.ENOTDIR):
-                writemsg("open('{}', 'r'): {}\n".format(newfile, e), noiselevel=-1)
+                writemsg(f"open('{newfile}', 'r'): {e}\n", noiselevel=-1)
                 raise
 
             msg = self.error_leader()
@@ -746,7 +745,7 @@ class _getconfig_shlex(shlex.shlex):
                 msg += _("%s: No such file or directory") % newfile
 
             if self.__portage_tolerant:
-                writemsg("%s\n" % msg, noiselevel=-1)
+                writemsg(f"{msg}\n", noiselevel=-1)
             else:
                 raise ParseError(msg)
             return (newfile, io.StringIO())
@@ -758,7 +757,6 @@ _invalid_var_name_re = re.compile(r"^\d|\W")
 def getconfig(
     mycfg, tolerant=False, allow_sourcing=False, expand=True, recursive=False
 ):
-
     if isinstance(expand, dict):
         # Some existing variable definitions have been
         # passed in, for use in substitutions.
@@ -801,7 +799,7 @@ def getconfig(
         if e.errno == PermissionDenied.errno:
             raise PermissionDenied(mycfg)
         if e.errno != errno.ENOENT:
-            writemsg("open('{}', 'r'): {}\n".format(mycfg, e), noiselevel=-1)
+            writemsg(f"open('{mycfg}', 'r'): {e}\n", noiselevel=-1)
             if e.errno not in (errno.EISDIR,):
                 raise
         return None
@@ -864,7 +862,7 @@ def getconfig(
                 if not tolerant:
                     raise ParseError(msg)
                 else:
-                    writemsg("%s\n" % msg, noiselevel=-1)
+                    writemsg(f"{msg}\n", noiselevel=-1)
                     return mykeys
 
             elif equ != "=":
@@ -872,7 +870,7 @@ def getconfig(
                 if not tolerant:
                     raise ParseError(msg)
                 else:
-                    writemsg("%s\n" % msg, noiselevel=-1)
+                    writemsg(f"{msg}\n", noiselevel=-1)
                     return mykeys
 
             val = _unicode_decode(lex.get_token())
@@ -883,14 +881,14 @@ def getconfig(
                 if not tolerant:
                     raise ParseError(msg)
                 else:
-                    writemsg("%s\n" % msg, noiselevel=-1)
+                    writemsg(f"{msg}\n", noiselevel=-1)
                     return mykeys
 
             if _invalid_var_name_re.search(key) is not None:
                 msg = lex.error_leader() + _("Invalid variable name '%s'") % (key,)
                 if not tolerant:
                     raise ParseError(msg)
-                writemsg("%s\n" % msg, noiselevel=-1)
+                writemsg(f"{msg}\n", noiselevel=-1)
                 continue
 
             if expand:
@@ -905,8 +903,8 @@ def getconfig(
     except Exception as e:
         if isinstance(e, ParseError) or lex is None:
             raise
-        msg = "{}{}".format(lex.error_leader(), e)
-        writemsg("%s\n" % msg, noiselevel=-1)
+        msg = f"{lex.error_leader()}{e}"
+        writemsg(f"{msg}\n", noiselevel=-1)
         raise
 
     return mykeys
@@ -1082,7 +1080,7 @@ def dump_traceback(msg, noiselevel=1):
         stack = traceback.extract_tb(info[2])
         error = str(info[1])
     writemsg("\n====================================\n", noiselevel=noiselevel)
-    writemsg("%s\n\n" % msg, noiselevel=noiselevel)
+    writemsg(f"{msg}\n\n", noiselevel=noiselevel)
     for line in traceback.format_list(stack):
         writemsg(line, noiselevel=noiselevel)
     if error:
@@ -1125,7 +1123,7 @@ class cmp_sort_key:
         def __lt__(self, other):
             if other.__class__ is not self.__class__:
                 raise TypeError(
-                    "Expected type {}, got {}".format(self.__class__, other.__class__)
+                    f"Expected type {self.__class__}, got {other.__class__}"
                 )
             return self._cmp_func(self._obj, other._obj) < 0
 
@@ -1192,7 +1190,7 @@ def _do_stat(filename, follow_links=True):
             return os.stat(filename)
         return os.lstat(filename)
     except OSError as oe:
-        func_call = "stat('%s')" % filename
+        func_call = f"stat('{filename}')"
         if oe.errno == errno.EPERM:
             raise OperationNotPermitted(func_call)
         if oe.errno == errno.EACCES:
@@ -1287,7 +1285,7 @@ def apply_permissions(
             os.chmod(filename, new_mode)
             modified = True
         except OSError as oe:
-            func_call = "chmod('{}', {})".format(filename, oct(new_mode))
+            func_call = f"chmod('{filename}', {oct(new_mode)})"
             if oe.errno == errno.EPERM:
                 raise OperationNotPermitted(func_call)
             elif oe.errno == errno.EACCES:
@@ -1409,7 +1407,6 @@ def apply_secpass_permissions(
     # Avoid accessing portage.data.secpass when possible, since
     # it triggers config loading (undesirable for chmod-lite).
     if (uid != -1 or gid != -1) and portage.data.secpass < 2:
-
         if uid != -1 and uid != stat_cached.st_uid:
             all_applied = False
             uid = -1
@@ -1460,7 +1457,7 @@ class atomic_ofstream(AbstractContextManager, ObjectProxy):
                             tmp_name, encoding=_encodings["fs"], errors="strict"
                         ),
                         mode=mode,
-                        **kargs
+                        **kargs,
                     ),
                 )
                 return
@@ -1479,7 +1476,7 @@ class atomic_ofstream(AbstractContextManager, ObjectProxy):
             open_func(
                 _unicode_encode(tmp_name, encoding=_encodings["fs"], errors="strict"),
                 mode=mode,
-                **kargs
+                **kargs,
             ),
         )
 
@@ -1560,7 +1557,7 @@ def write_atomic(file_path, content, **kwargs):
     except OSError as e:
         if f:
             f.abort()
-        func_call = "write_atomic('%s')" % file_path
+        func_call = f"write_atomic('{file_path}')"
         if e.errno == errno.EPERM:
             raise OperationNotPermitted(func_call)
         elif e.errno == errno.EACCES:
@@ -1589,7 +1586,7 @@ def ensure_dirs(dir_path, **kwargs):
         os.makedirs(dir_path)
         created_dir = True
     except OSError as oe:
-        func_call = "makedirs('%s')" % dir_path
+        func_call = f"makedirs('{dir_path}')"
         if oe.errno in (errno.EEXIST,):
             pass
         else:
@@ -1622,7 +1619,6 @@ class LazyItemsDict(UserDict):
     __slots__ = ("lazy_items",)
 
     def __init__(self, *args, **kwargs):
-
         self.lazy_items = {}
         UserDict.__init__(self, *args, **kwargs)
 
@@ -1718,21 +1714,15 @@ class LazyItemsDict(UserDict):
                     raise TypeError(
                         "LazyItemsDict "
                         + "deepcopy is unsafe with lazy items that are "
-                        + "not singletons: key=%s value=%s"
-                        % (
-                            k,
-                            lazy_item,
-                        )
+                        + f"not singletons: key={k} value={lazy_item}"
                     )
             UserDict.__setitem__(result, k_copy, deepcopy(self[k], memo))
         return result
 
     class _LazyItem:
-
         __slots__ = ("func", "pargs", "kwargs", "singleton")
 
         def __init__(self, func, pargs, kwargs, singleton):
-
             if not pargs:
                 pargs = None
             if not kwargs:
@@ -1962,7 +1952,7 @@ def find_updated_config_files(target_root, config_protect):
 
             if stat.S_ISDIR(mymode):
                 mycommand = (
-                    "find '%s' -name '.*' -type d -prune -o -name '._cfg????_*'" % x
+                    f"find '{x}' -name '.*' -type d -prune -o -name '._cfg????_*'"
                 )
             else:
                 mycommand = (
